@@ -14,8 +14,8 @@
 //! ## Version numbers
 //!
 //! The client library MAJOR and MINOR version follow a particular
-//! Ratman release.  So for example, version `0.3.0` of this crate is
-//! built against version `0.3.0` of `ratmand`.  Because Ratman itself
+//! Ratman release.  So for example, version `0.4.0` of this crate is
+//! built against version `0.4.0` of `ratmand`.  Because Ratman itself
 //! follows semantic versioning, this crate is in turn also
 //! semantically versioned.
 //!
@@ -35,16 +35,21 @@ use async_std::{
     net::TcpStream,
     task,
 };
-pub use types::{api::Receive_Type, message::Message, Error, Identity, Result};
+pub use types::{api::Receive_Type, Error, Identity, Message, Result, TimePair};
 use types::{
     api::{
         self, ApiMessageEnum,
         Peers_Type::{DISCOVER, RESP},
         Setup_Type::ACK,
     },
-    encode_message, message, parse_message, read_with_length, write_with_length,
+    encode_message, parse_message, read_with_length, write_with_length,
 };
 
+/// An IPC handle for a particular address
+///
+/// This handle can be cloned safely.  An Ipc handle only refers to a
+/// single address connection.  Your application is encouraged to
+/// maintain many of these connections at the same time.
 #[derive(Clone)]
 pub struct RatmanIpc {
     socket: TcpStream,
@@ -60,7 +65,7 @@ impl RatmanIpc {
     }
 
     pub async fn default_with_addr(addr: Identity) -> Result<Self> {
-        Self::connect("127.0.0.1:920", Some(addr)).await
+        Self::connect("127.0.0.1:9020", Some(addr)).await
     }
 
     /// Connect to a Ratman IPC backend with an optional address
@@ -134,12 +139,15 @@ impl RatmanIpc {
 
     /// Send some data to a remote peer
     pub async fn send_to(&self, recipient: Identity, payload: Vec<u8>) -> Result<()> {
-        let msg = api::api_send(api::send_default(message::new(
-            self.addr,
-            vec![recipient], // recipient
-            payload,
-            vec![], // signature
-        )));
+        let msg = api::api_send(api::send_default(
+            Message::new(
+                self.addr,
+                vec![recipient], // recipient
+                payload,
+                vec![], // signature
+            )
+            .into(),
+        ));
 
         write_with_length(&mut self.socket.clone(), &encode_message(msg)?).await?;
         Ok(())
@@ -147,12 +155,15 @@ impl RatmanIpc {
 
     /// Send some data to a remote peer
     pub async fn flood(&self, payload: Vec<u8>) -> Result<()> {
-        let msg = api::api_send(api::send_flood(message::new(
-            self.addr,
-            vec![], // recipient
-            payload,
-            vec![], // signature
-        )));
+        let msg = api::api_send(api::send_flood(
+            Message::new(
+                self.addr,
+                vec![], // recipient
+                payload,
+                vec![], // signature
+            )
+            .into(),
+        ));
 
         write_with_length(&mut self.socket.clone(), &encode_message(msg)?).await?;
         Ok(())
@@ -172,7 +183,7 @@ impl RatmanIpc {
     pub async fn get_peers(&self) -> Result<Vec<Identity>> {
         let msg = api::api_peers(api::peers_req());
         write_with_length(&mut self.socket.clone(), &encode_message(msg)?).await?;
-        
+
         match parse_message(&mut self.socket.clone())
             .await
             .map(|m| m.inner)
@@ -211,7 +222,7 @@ async fn run_receive(
                     let msg = msg.take_msg();
 
                     debug!("Forwarding message to IPC wrapper");
-                    if let Err(e) = tx.send((tt, msg)).await {
+                    if let Err(e) = tx.send((tt, msg.into())).await {
                         error!("Failed to forward received message: {}", e);
                     }
                 }
@@ -238,6 +249,7 @@ async fn run_receive(
 }
 
 /// This test is horrible and a bad idea but whatever
+/// also you need to kill the daemon(kill process) after the test
 #[async_std::test]
 #[ignore]
 async fn send_message() {
@@ -268,7 +280,8 @@ async fn send_message() {
             "--features",
             "daemon",
             "--",
-            "--no-peering",
+            "--no-inet",
+            "--accept-unknown-peers",
         ])
         .spawn()
         .unwrap();
